
# #oneweekchallenge


* DB_Query() 
* DB_Model() +
* DB_Field() +
  * .TextField +
  * .CharField + verified
  * .DateField +
  * .DateTimeField +
  * .TimeField +
  * .BooleanField +
  * .IntegerField +
  * .JsonField + verified
  * .IDField + verified
  * .URLField +
  * .SlugField +
  * .FileField + verified
  * .ImageField + verified
  * .FloatField +
  * .EmailField + verified
  * .ForeignKeyField +

* DB_Validator()  
  * .SpecialCharValidator +
  * .LengthValidator +
  * .BigLetterValidator +
  * .SmallLetterValidator +
  * .EmailValidator +
  * .NumberValidator +

* Utilities
  * StringStructureParser() <code><a>@<c>.<e></code> +

* DB_Error()
  * .NotFoundKwarg +
  * .ModelError +
  * .OperationError
  * .QueryError +
  * .FieldError +
  * .ValidatorError +
  * .SettingError
  * .StructureError

* Structure
-----
* Options
  * opt_İD
  * opt_label
  * opt_value
  * auto_load




